# Generated by Django 3.2.4 on 2021-07-26 00:40

import _socket
from django.conf import settings
import django.contrib.sites.managers
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0011_auto_20210624_0225"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("meta_subject", "0066_auto_20210721_0335"),
    ]

    operations = [
        migrations.CreateModel(
            name="ComplicationsGlycemia",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.models.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "cataracts",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Presence of cataracts",
                    ),
                ),
                (
                    "fundoscopy",
                    models.CharField(
                        choices=[
                            ("no_retinopathy", "No retinopathy"),
                            ("background_retinopathy", "Background retinopathy"),
                            (
                                "pre_proliferative_retinopathy",
                                "Pre-proliferative retinopathy",
                            ),
                            ("proliferative_retinopathy", "Proliferative retinopathy"),
                            ("maculopathy", "Maculopathy"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=35,
                        verbose_name="Fundoscopy",
                    ),
                ),
                (
                    "foot_skin_condition",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Is the skin of the foot intact and in good condition?",
                    ),
                ),
                (
                    "foot_fungal_infection",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Is there any fungal infection on the foot?",
                    ),
                ),
                (
                    "foot_sores",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are there any foot sores?",
                    ),
                ),
                (
                    "foot_callouses",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are there any callouses on the foot?",
                    ),
                ),
                (
                    "dp_pulse",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Dorsalis pedis pulse",
                    ),
                ),
                (
                    "pt_pulse",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Posterior tibial pulse",
                    ),
                ),
                (
                    "at_reflex",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Achilles tendon reflex",
                    ),
                ),
                (
                    "nds_vpt_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="128-Hz tuning fork; apex of big toe. Normal: can distinguish vibrating/Not vibrating",
                        max_length=15,
                        verbose_name="Vibration perception threshold (left)",
                    ),
                ),
                (
                    "nds_vpt_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="128-Hz tuning fork; apex of big toe. Normal: can distinguish vibrating/Not vibrating",
                        max_length=15,
                        verbose_name="Vibration perception threshold (right)",
                    ),
                ),
                (
                    "nds_tp_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Temperature perception on dorsum of foot (left)",
                    ),
                ),
                (
                    "nds_tp_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Temperature perception on dorsum of foot (right)",
                    ),
                ),
                (
                    "nds_pp_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Pin-Prick (left)",
                    ),
                ),
                (
                    "nds_pp_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Pin-Prick (right)",
                    ),
                ),
                (
                    "nds_achilles_reflex_left",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            (
                                "present_with_reinforcement",
                                "Present with reinforcement",
                            ),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=30,
                        verbose_name="Achilles reflex (left)",
                    ),
                ),
                (
                    "nds_achilles_reflex_right",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            (
                                "present_with_reinforcement",
                                "Present with reinforcement",
                            ),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=30,
                        verbose_name="Achilles reflex (right)",
                    ),
                ),
                (
                    "first_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="First metatarsal (left)",
                    ),
                ),
                (
                    "first_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="First metatarsal (right)",
                    ),
                ),
                (
                    "third_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Third metatarsal (left)",
                    ),
                ),
                (
                    "third_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Third metatarsal (right)",
                    ),
                ),
                (
                    "fifth_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Fifth metatarsal (left)",
                    ),
                ),
                (
                    "fifth_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Fifth metatarsal (right)",
                    ),
                ),
                (
                    "plantar_surface_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Plantar surface of distal hallux (left)",
                    ),
                ),
                (
                    "plantar_surface_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Plantar surface of distal hallux (right)",
                    ),
                ),
                (
                    "dns_walking",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are you experiencing unsteadiness in walking?",
                    ),
                ),
                (
                    "dns_burning",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Do you have burning, aching pain or tenderness in your legs or feet?",
                    ),
                ),
                (
                    "dns_tingling",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Do you have prickling or tingling sensation in your legs or feet?",
                    ),
                ),
                (
                    "dns_numbness",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are you experiencing any numbness or loss of feeling in your legs or feet?",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Complications (Raised Glycemia)",
                "verbose_name_plural": "Complications (Raised Glycemia)",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalComplicationsGlycemia",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.models.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "cataracts",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Presence of cataracts",
                    ),
                ),
                (
                    "fundoscopy",
                    models.CharField(
                        choices=[
                            ("no_retinopathy", "No retinopathy"),
                            ("background_retinopathy", "Background retinopathy"),
                            (
                                "pre_proliferative_retinopathy",
                                "Pre-proliferative retinopathy",
                            ),
                            ("proliferative_retinopathy", "Proliferative retinopathy"),
                            ("maculopathy", "Maculopathy"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=35,
                        verbose_name="Fundoscopy",
                    ),
                ),
                (
                    "foot_skin_condition",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Is the skin of the foot intact and in good condition?",
                    ),
                ),
                (
                    "foot_fungal_infection",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Is there any fungal infection on the foot?",
                    ),
                ),
                (
                    "foot_sores",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are there any foot sores?",
                    ),
                ),
                (
                    "foot_callouses",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are there any callouses on the foot?",
                    ),
                ),
                (
                    "dp_pulse",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Dorsalis pedis pulse",
                    ),
                ),
                (
                    "pt_pulse",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Posterior tibial pulse",
                    ),
                ),
                (
                    "at_reflex",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Achilles tendon reflex",
                    ),
                ),
                (
                    "nds_vpt_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="128-Hz tuning fork; apex of big toe. Normal: can distinguish vibrating/Not vibrating",
                        max_length=15,
                        verbose_name="Vibration perception threshold (left)",
                    ),
                ),
                (
                    "nds_vpt_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="128-Hz tuning fork; apex of big toe. Normal: can distinguish vibrating/Not vibrating",
                        max_length=15,
                        verbose_name="Vibration perception threshold (right)",
                    ),
                ),
                (
                    "nds_tp_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Temperature perception on dorsum of foot (left)",
                    ),
                ),
                (
                    "nds_tp_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Temperature perception on dorsum of foot (right)",
                    ),
                ),
                (
                    "nds_pp_left",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Pin-Prick (left)",
                    ),
                ),
                (
                    "nds_pp_right",
                    models.CharField(
                        choices=[
                            ("NORMAL", "Normal"),
                            ("ABNORMAL", "Abnormal"),
                            ("NO_EXAM", "No exam performed"),
                        ],
                        help_text="Use tuning fork with beaker of ice/warm water",
                        max_length=15,
                        verbose_name="Pin-Prick (right)",
                    ),
                ),
                (
                    "nds_achilles_reflex_left",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            (
                                "present_with_reinforcement",
                                "Present with reinforcement",
                            ),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=30,
                        verbose_name="Achilles reflex (left)",
                    ),
                ),
                (
                    "nds_achilles_reflex_right",
                    models.CharField(
                        choices=[
                            ("present", "Present"),
                            (
                                "present_with_reinforcement",
                                "Present with reinforcement",
                            ),
                            ("absent", "Absent"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=30,
                        verbose_name="Achilles reflex (right)",
                    ),
                ),
                (
                    "first_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="First metatarsal (left)",
                    ),
                ),
                (
                    "first_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="First metatarsal (right)",
                    ),
                ),
                (
                    "third_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Third metatarsal (left)",
                    ),
                ),
                (
                    "third_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Third metatarsal (right)",
                    ),
                ),
                (
                    "fifth_metatarsal_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Fifth metatarsal (left)",
                    ),
                ),
                (
                    "fifth_metatarsal_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Fifth metatarsal (right)",
                    ),
                ),
                (
                    "plantar_surface_left",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Plantar surface of distal hallux (left)",
                    ),
                ),
                (
                    "plantar_surface_right",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Plantar surface of distal hallux (right)",
                    ),
                ),
                (
                    "dns_walking",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are you experiencing unsteadiness in walking?",
                    ),
                ),
                (
                    "dns_burning",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Do you have burning, aching pain or tenderness in your legs or feet?",
                    ),
                ),
                (
                    "dns_tingling",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Do you have prickling or tingling sensation in your legs or feet?",
                    ),
                ),
                (
                    "dns_numbness",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("NO_EXAM", "Exam not performed"),
                        ],
                        max_length=15,
                        verbose_name="Are you experiencing any numbness or loss of feeling in your legs or feet?",
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Complications (Raised Glycemia)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.RemoveField(
            model_name="historicaladditionalscreening",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicaladditionalscreening",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicaladditionalscreening",
            name="subject_visit",
        ),
        migrations.AlterField(
            model_name="complications",
            name="fundoscopy",
            field=models.CharField(
                choices=[
                    ("no_retinopathy", "No retinopathy"),
                    ("background_retinopathy", "Background retinopathy"),
                    ("pre_proliferative_retinopathy", "Pre-proliferative retinopathy"),
                    ("proliferative_retinopathy", "Proliferative retinopathy"),
                    ("maculopathy", "Maculopathy"),
                    ("NO_EXAM", "Exam not performed"),
                ],
                max_length=35,
                verbose_name="Fundoscopy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="fundoscopy",
            field=models.CharField(
                choices=[
                    ("no_retinopathy", "No retinopathy"),
                    ("background_retinopathy", "Background retinopathy"),
                    ("pre_proliferative_retinopathy", "Pre-proliferative retinopathy"),
                    ("proliferative_retinopathy", "Proliferative retinopathy"),
                    ("maculopathy", "Maculopathy"),
                    ("NO_EXAM", "Exam not performed"),
                ],
                max_length=35,
                verbose_name="Fundoscopy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="other_missed_pill_reason",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="other_missed_pill_reason",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="missed_reasons",
            field=models.ManyToManyField(
                blank=True,
                related_name="meta_missed_reasons",
                to="meta_lists.SubjectVisitMissedReasons",
            ),
        ),
        migrations.DeleteModel(
            name="AdditionalScreening",
        ),
        migrations.DeleteModel(
            name="HistoricalAdditionalScreening",
        ),
        migrations.AddIndex(
            model_name="complicationsglycemia",
            index=models.Index(
                fields=["subject_visit", "site", "id"],
                name="meta_subjec_subject_3c1655_idx",
            ),
        ),
    ]



from django.db import migrations


def update_subject_visit_metadata(apps, schema_editor):
    subject_visit_model_cls = apps.get_model("meta_subject.subjectvisit")
    for obj in subject_visit_model_cls.objects.all():
        obj.save()


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0047_auto_20200530_1819"),
    ]

    operations = [migrations.RunPython(update_subject_visit_metadata)]



from django import forms
from edc_form_validators import FormValidator, FormValidatorMixin
from edc_visit_tracking.modelform_mixins import get_subject_visit

from ..models import OtherArvRegimensDetail


class OtherArvRegimensDetailFormValidator(FormValidator):
    def clean(self):
        if not self.cleaned_data.get("DELETE"):
            self.validate_other_specify(
                field="arv_regimen", other_specify_field="other_arv_regimen"
            )
            self.required_if_true(
                self.cleaned_data.get("arv_regimen"),
                field_required="arv_regimen_start_date",
            )


class InlineCrfModelFormMixin(FormValidatorMixin, forms.ModelForm):
    @property
    def subject_visit(self):
        return get_subject_visit(self, subject_visit_attr=self.subject_visit_attr)

    @property
    def subject_visit_attr(self):
        return self._meta.model.visit_model_attr()


class OtherArvRegimensDetailForm(InlineCrfModelFormMixin, forms.ModelForm):

    form_validator_cls = OtherArvRegimensDetailFormValidator

    class Meta:
        model = OtherArvRegimensDetail
        fields = "__all__"



# Generated by Django 3.2.11 on 2022-04-03 11:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0041_auto_20220403_1227'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalscreeningpartone',
            name='fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartone',
            name='fbg2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartone',
            name='ogtt2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartone',
            name='repeat_fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartthree',
            name='fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartthree',
            name='fbg2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningpartthree',
            name='repeat_fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningparttwo',
            name='fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningparttwo',
            name='fbg2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalscreeningparttwo',
            name='repeat_fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalsubjectscreening',
            name='fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='historicalsubjectscreening',
            name='fbg2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalsubjectscreening',
            name='ogtt2_performed',
        ),
        migrations.RemoveField(
            model_name='historicalsubjectscreening',
            name='repeat_fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='subjectscreening',
            name='fasting_opinion',
        ),
        migrations.RemoveField(
            model_name='subjectscreening',
            name='fbg2_performed',
        ),
        migrations.RemoveField(
            model_name='subjectscreening',
            name='ogtt2_performed',
        ),
        migrations.RemoveField(
            model_name='subjectscreening',
            name='repeat_fasting_opinion',
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='art_six_months',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Has the patient been on anti-retroviral therapy for <u>at least 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the <u>META Phase 2</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='repeat_glucose_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='No', help_text='If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)', max_length=15, verbose_name='In opinion of the clinician, should the glucose measurements be repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='screening_consent',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the subject given his/her verbal consent to be screened for the <u>META Phase 3</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='staying_nearby_12',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Is the patient planning to remain in the catchment area for <u>at least 12 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Does the patient have a viral load measure of less than 400 copies per ml taken <u>within the last 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='art_six_months',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Has the patient been on anti-retroviral therapy for <u>at least 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the <u>META Phase 2</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='repeat_glucose_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='No', help_text='If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)', max_length=15, verbose_name='In opinion of the clinician, should the glucose measurements be repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='screening_consent',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the subject given his/her verbal consent to be screened for the <u>META Phase 3</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='staying_nearby_12',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Is the patient planning to remain in the catchment area for <u>at least 12 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Does the patient have a viral load measure of less than 400 copies per ml taken <u>within the last 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='art_six_months',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Has the patient been on anti-retroviral therapy for <u>at least 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the <u>META Phase 2</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='repeat_glucose_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='No', help_text='If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)', max_length=15, verbose_name='In opinion of the clinician, should the glucose measurements be repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='screening_consent',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the subject given his/her verbal consent to be screened for the <u>META Phase 3</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='staying_nearby_12',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Is the patient planning to remain in the catchment area for <u>at least 12 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Does the patient have a viral load measure of less than 400 copies per ml taken <u>within the last 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='art_six_months',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Has the patient been on anti-retroviral therapy for <u>at least 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the <u>META Phase 2</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='repeat_glucose_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='No', help_text='If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)', max_length=15, verbose_name='In opinion of the clinician, should the glucose measurements be repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='screening_consent',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the subject given his/her verbal consent to be screened for the <u>META Phase 3</u> trial?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='staying_nearby_12',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Is the patient planning to remain in the catchment area for <u>at least 12 months</u>'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Does the patient have a viral load measure of less than 400 copies per ml taken <u>within the last 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='art_six_months',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Has the patient been on anti-retroviral therapy for <u>at least 6 months</u>'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='meta_phase_two',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Was the subject enrolled in the <u>META Phase 2</u> trial?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='repeat_glucose_opinion',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='No', help_text='If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)', max_length=15, verbose_name='In opinion of the clinician, should the glucose measurements be repeated?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='screening_consent',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the subject given his/her verbal consent to be screened for the <u>META Phase 3</u> trial?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='staying_nearby_12',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Is the patient planning to remain in the catchment area for <u>at least 12 months</u>'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='vl_undetectable',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], max_length=15, verbose_name='Does the patient have a viral load measure of less than 400 copies per ml taken <u>within the last 6 months</u>'),
        ),
    ]



# Generated by Django 2.2.6 on 2019-11-01 21:33

import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("meta_ae", "0002_auto_20191024_1000")]

    operations = [
        migrations.AlterField(
            model_name="aeinitial",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="other_informant_relationship",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="other_informant_relationship",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]



from dateutil.relativedelta import relativedelta
from edc_visit_schedule import Schedule
from edc_visit_schedule import Visit as BaseVisit

from ...constants import (
    DAY1,
    MONTH1,
    MONTH3,
    MONTH6,
    MONTH9,
    MONTH12,
    MONTH15,
    MONTH18,
    MONTH21,
    MONTH24,
    MONTH27,
    MONTH30,
    MONTH33,
    MONTH36,
    SCHEDULE,
    WEEK2,
)
from .crfs import (
    crfs_1m,
    crfs_3m,
    crfs_6m,
    crfs_9m,
    crfs_12m,
    crfs_15m,
    crfs_18m,
    crfs_21m,
    crfs_24m,
    crfs_27m,
    crfs_30m,
    crfs_33m,
    crfs_36m,
    crfs_d1,
    crfs_missed,
)
from .crfs import crfs_prn as default_crfs_prn
from .crfs import crfs_unscheduled as default_crfs_unscheduled
from .crfs import crfs_w2
from .requisitions import (
    requisitions_1m,
    requisitions_3m,
    requisitions_6m,
    requisitions_9m,
    requisitions_12m,
    requisitions_15m,
    requisitions_18m,
    requisitions_21m,
    requisitions_24m,
    requisitions_27m,
    requisitions_30m,
    requisitions_33m,
    requisitions_36m,
    requisitions_d1,
)
from .requisitions import requisitions_prn as default_requisitions_prn
from .requisitions import requisitions_unscheduled as default_requisitions_unscheduled
from .requisitions import requisitions_w2


class Visit(BaseVisit):
    def __init__(
        self,
        crfs_unscheduled=None,
        requisitions_unscheduled=None,
        crfs_prn=None,
        requisitions_prn=None,
        allow_unscheduled=None,
        **kwargs
    ):
        super().__init__(
            allow_unscheduled=True if allow_unscheduled is None else allow_unscheduled,
            crfs_unscheduled=crfs_unscheduled or default_crfs_unscheduled,
            requisitions_unscheduled=requisitions_unscheduled
            or default_requisitions_unscheduled,
            crfs_prn=crfs_prn or default_crfs_prn,
            requisitions_prn=requisitions_prn or default_requisitions_prn,
            crfs_missed=crfs_missed,
            **kwargs,
        )


# schedule for new participants
schedule = Schedule(
    name=SCHEDULE,
    verbose_name="Day 1 to Month 12 Follow-up",
    onschedule_model="meta_prn.onschedule",
    offschedule_model="meta_prn.offschedule",
    consent_model="meta_consent.subjectconsent",
    appointment_model="edc_appointment.appointment",
)


visit000 = Visit(
    code=DAY1,
    title="Day 1",
    timepoint=0,
    rbase=relativedelta(days=0),
    rlower=relativedelta(days=0),
    rupper=relativedelta(days=0),
    requisitions=requisitions_d1,
    crfs=crfs_d1,
    facility_name="7-day-clinic",
)

visit002 = Visit(
    code=WEEK2,
    title="Week 2",
    timepoint=1,
    rbase=relativedelta(weeks=2),
    rlower=relativedelta(days=3),
    rupper=relativedelta(days=4),
    requisitions=requisitions_w2,
    crfs=crfs_w2,
    facility_name="7-day-clinic",
)

visit01 = Visit(
    code=MONTH1,
    title="Month 1",
    timepoint=2,
    rbase=relativedelta(months=1),
    rlower=relativedelta(days=15),
    rupper=relativedelta(days=30),
    requisitions=requisitions_1m,
    crfs=crfs_1m,
    facility_name="7-day-clinic",
)


visit03 = Visit(
    code=MONTH3,
    title="Month 3",
    timepoint=3,
    rbase=relativedelta(months=3),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_3m,
    crfs=crfs_3m,
    facility_name="7-day-clinic",
)

visit06 = Visit(
    code=MONTH6,
    title="Month 6",
    timepoint=4,
    rbase=relativedelta(months=6),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_6m,
    crfs=crfs_6m,
    facility_name="7-day-clinic",
)

visit09 = Visit(
    code=MONTH9,
    title="Month 9",
    timepoint=5,
    rbase=relativedelta(months=9),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_9m,
    crfs=crfs_9m,
    facility_name="7-day-clinic",
)
visit12 = Visit(
    code=MONTH12,
    title="Month 12",
    timepoint=6,
    rbase=relativedelta(months=12),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_12m,
    crfs=crfs_12m,
    facility_name="7-day-clinic",
)

visit15 = Visit(
    code=MONTH15,
    title="Month 15",
    timepoint=7,
    rbase=relativedelta(months=15),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_15m,
    crfs=crfs_15m,
    facility_name="7-day-clinic",
)

visit18 = Visit(
    code=MONTH18,
    title="Month 18",
    timepoint=8,
    rbase=relativedelta(months=18),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_18m,
    crfs=crfs_18m,
    facility_name="7-day-clinic",
)

visit21 = Visit(
    code=MONTH21,
    title="Month 21",
    timepoint=9,
    rbase=relativedelta(months=21),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_21m,
    crfs=crfs_21m,
    facility_name="7-day-clinic",
)

visit24 = Visit(
    code=MONTH24,
    title="Month 24",
    timepoint=10,
    rbase=relativedelta(months=24),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_24m,
    crfs=crfs_24m,
    facility_name="7-day-clinic",
)

visit27 = Visit(
    code=MONTH27,
    title="Month 27",
    timepoint=11,
    rbase=relativedelta(months=27),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_27m,
    crfs=crfs_27m,
    facility_name="7-day-clinic",
)

visit30 = Visit(
    code=MONTH30,
    title="Month 30",
    timepoint=12,
    rbase=relativedelta(months=30),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_30m,
    crfs=crfs_30m,
    facility_name="7-day-clinic",
)

visit33 = Visit(
    code=MONTH33,
    title="Month 33",
    timepoint=13,
    rbase=relativedelta(months=33),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=2),
    requisitions=requisitions_33m,
    crfs=crfs_33m,
    facility_name="7-day-clinic",
)

visit36 = Visit(
    code=MONTH36,
    title="Month 36",
    timepoint=14,
    rbase=relativedelta(months=36),
    rlower=relativedelta(months=1),
    rupper=relativedelta(months=1),
    requisitions=requisitions_36m,
    crfs=crfs_36m,
    facility_name="7-day-clinic",
)


visits = [
    visit000,
    visit002,
    visit01,
    visit03,
    visit06,
    visit09,
    visit12,
    visit15,
    visit18,
    visit21,
    visit24,
    visit27,
    visit30,
    visit33,
    visit36,
]
for visit in visits:
    schedule.add_visit(visit=visit)



from .end_of_study_admin import EndOfStudyPhaseThreeAdmin
from .loss_to_followup_admin import LossToFollowupAdmin
from .offschedule_admin import OffScheduleAdmin
from .offschedule_postnatal_admin import OffSchedulePostnatalAdmin
from .offschedule_pregnancy_admin import OffSchedulePregnancyAdmin
from .onschedule_admin import OnScheduleAdmin
from .pregnancy_notification_admin import PregnancyNotificationAdmin
from .protocol_deviation_violation_admin import ProtocolDeviationViolationAdmin



from .eligibility import MetaEligibility, SubjectScreeningEligibilityError
from .eligibility_part_one import EligibilityPartOne
from .eligibility_part_three import EligibilityPartThreePhaseThree
from .eligibility_part_two import EligibilityPartTwo
from .utils import format_reasons_ineligible



from django.db import models
from edc_constants.choices import YES_NO_TBD
from edc_constants.constants import TBD
from edc_reportable.units import MICROMOLES_PER_LITER_DISPLAY, MILLIMOLES_PER_LITER


class CalculatedModelMixin(models.Model):

    # calculated
    calculated_egfr_value = models.DecimalField(
        verbose_name="eGFR",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text="mL/min/1.73m2 (system calculated)",
    )

    # converted if necessary
    converted_creatinine_value = models.DecimalField(
        verbose_name="Serum creatinine",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text=f"{MICROMOLES_PER_LITER_DISPLAY} (system converted)",
    )

    # converted if necessary
    converted_fbg_value = models.DecimalField(
        verbose_name="FBG level",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text=f"{MILLIMOLES_PER_LITER} (system converted)",
    )

    converted_fbg2_value = models.DecimalField(
        verbose_name="Repeat FBG level",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text=f"{MILLIMOLES_PER_LITER} (system converted)",
    )

    # converted if necessary
    converted_ogtt_value = models.DecimalField(
        verbose_name="OGTT (2-hours)",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text=f"{MILLIMOLES_PER_LITER} (system converted)",
    )

    # converted if necessary
    converted_ogtt2_value = models.DecimalField(
        verbose_name="Repeat OGTT (2-hours)",
        max_digits=8,
        decimal_places=4,
        null=True,
        help_text=f"{MILLIMOLES_PER_LITER} (system converted)",
    )

    # calculated
    inclusion_a = models.CharField(
        verbose_name="BMI>30 combined with FBG (6.1 to 6.9 mmol/L)",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        help_text="system calculated",
    )

    # calculated
    inclusion_b = models.CharField(
        verbose_name="BMI>30 combined with OGTT (2 hours) (7.0 to 11.10 mmol/L)",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        help_text="system calculated",
    )

    # calculated
    inclusion_c = models.CharField(
        verbose_name="BMI<=30 combined with FBG (6.3 to 6.9 mmol/L)",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        help_text="system calculated",
    )

    # calculated
    inclusion_d = models.CharField(
        verbose_name="BMI<=30 combined with OGTT (2 hours) (9.0 to 11.10 mmol/L)",
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        help_text="system calculated",
    )

    class Meta:
        abstract = True



from dateutil.relativedelta import relativedelta
from django import forms
from django.test import TestCase
from edc_consent.constants import HOSPITAL_NUMBER
from edc_constants.constants import FEMALE
from edc_utils.date import get_utcnow
from pytz import timezone

from meta_consent.forms import SubjectConsentFormValidator
from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin


class TestFormValidators(MetaTestCaseMixin, TestCase):
    def setUp(self):
        super().setUp()
        self.eligibility_datetime = get_utcnow() - relativedelta(days=1)  # yesterday
        self.subject_screening = self.get_subject_screening(
            report_datetime=get_utcnow(), eligibility_datetime=self.eligibility_datetime
        )
        self.screening_identifier = self.subject_screening.screening_identifier

    @staticmethod
    def get_now():
        return get_utcnow().astimezone(timezone("Africa/Dar_es_Salaam"))

    def test_ok(self):
        consent_datetime = self.get_now()
        cleaned_data = dict(
            screening_identifier=self.screening_identifier,
            gender=FEMALE,
            dob=self.subject_screening.report_datetime.date() - relativedelta(years=25),
            consent_datetime=consent_datetime,
            identity_type=HOSPITAL_NUMBER,
            identity=self.subject_screening.hospital_identifier,
            confirm_identity=self.subject_screening.hospital_identifier,
        )
        validator = SubjectConsentFormValidator(
            cleaned_data=cleaned_data,
        )
        validator.clean()

    def test_consent_before_eligibility_datetime(self):
        consent_datetime = self.subject_screening.eligibility_datetime - relativedelta(
            minutes=1
        )
        consent_datetime = consent_datetime.astimezone(timezone("Africa/Dar_es_Salaam"))
        cleaned_data = dict(
            screening_identifier=self.screening_identifier,
            gender=FEMALE,
            dob=self.subject_screening.report_datetime.date() - relativedelta(years=25),
            consent_datetime=consent_datetime,
            identity_type=HOSPITAL_NUMBER,
            identity=self.subject_screening.hospital_identifier,
            confirm_identity=self.subject_screening.hospital_identifier,
        )
        validator = SubjectConsentFormValidator(
            cleaned_data=cleaned_data,
        )
        self.assertRaises(forms.ValidationError, validator.clean)
        with self.assertRaises(forms.ValidationError) as cm:
            validator.clean()
        self.assertIn("consent_datetime", str(cm.exception))

    def test_consent_after_eligibility_datetime(self):
        consent_datetime = self.subject_screening.eligibility_datetime + relativedelta(
            minutes=1
        )
        consent_datetime = consent_datetime.astimezone(timezone("Africa/Dar_es_Salaam"))
        cleaned_data = dict(
            screening_identifier=self.screening_identifier,
            gender=FEMALE,
            dob=self.subject_screening.report_datetime.date() - relativedelta(years=25),
            consent_datetime=consent_datetime,
            identity_type=HOSPITAL_NUMBER,
            identity=self.subject_screening.hospital_identifier,
            confirm_identity=self.subject_screening.hospital_identifier,
        )
        validator = SubjectConsentFormValidator(
            cleaned_data=cleaned_data,
        )
        try:
            validator.clean()
        except forms.ValidationError:
            self.fail("ValidationError unexpectedly raised")



# Generated by Django 3.2.4 on 2021-06-28 18:05

import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import edc_visit_tracking.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0052_auto_20210624_0225"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="bloodresultsfbc",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsglu",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultshba1c",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslft",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslipid",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsrft",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="fbc_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="haemoglobin",
            new_name="haemoglobin_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="hct",
            new_name="hct_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="platelets",
            new_name="platelets_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="rbc",
            new_name="rbc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="wbc",
            new_name="wbc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_abnormal",
            new_name="gluc_abnormal",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_quantifier",
            new_name="gluc_quantifier",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_reportable",
            new_name="gluc_reportable",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_units",
            new_name="gluc_units",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose",
            new_name="gluc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="albumin",
            new_name="albumin_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="alp",
            new_name="alp_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="alt",
            new_name="alt_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="lft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="ast",
            new_name="ast_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="ggt",
            new_name="ggt_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="rft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="egfr",
            new_name="egfr_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="urea",
            new_name="urea_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="uric_acid",
            new_name="uric_acid_value",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="fbc_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="haemoglobin",
            new_name="haemoglobin_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="hct",
            new_name="hct_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="platelets",
            new_name="platelets_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="rbc",
            new_name="rbc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="fbc_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="wbc",
            new_name="wbc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_abnormal",
            new_name="gluc_abnormal",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_quantifier",
            new_name="gluc_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_reportable",
            new_name="gluc_reportable",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_units",
            new_name="gluc_units",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose",
            new_name="gluc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="albumin",
            new_name="albumin_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="alp",
            new_name="alp_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="alt",
            new_name="alt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="lft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="ast",
            new_name="ast_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="ggt",
            new_name="ggt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="lft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="rft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="egfr",
            new_name="egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="rft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="urea",
            new_name="urea_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="uric_acid",
            new_name="uric_acid_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        #
        #
        #
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="fbc_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="amylase",
            new_name="amylase_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="lft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="rft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="amylase",
            new_name="amylase_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="hba1c_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="hba1c_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL")],
                max_length=25,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="urea_units",
            field=models.CharField(
                blank=True,
                choices=[("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL")],
                max_length=25,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="urea_units",
            field=models.CharField(
                blank=True,
                choices=[("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="hba1c_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="amylase_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=6, null=True
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="amylase_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=6, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-03-12 00:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0036_auto_20220304_2307'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='repeat_fbg_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first FBG measures', max_length=15, verbose_name='Was the FBG repeated?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='repeat_ogtt_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first OGTT measures', max_length=15, verbose_name='Was the OGTT repeated?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='repeat_fbg_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first FBG measures', max_length=15, verbose_name='Was the FBG repeated?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='repeat_ogtt_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first OGTT measures', max_length=15, verbose_name='Was the OGTT repeated?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='repeat_fbg_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first FBG measures', max_length=15, verbose_name='Was the FBG repeated?'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='repeat_ogtt_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first OGTT measures', max_length=15, verbose_name='Was the OGTT repeated?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='repeat_fbg_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first FBG measures', max_length=15, verbose_name='Was the FBG repeated?'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='repeat_ogtt_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first OGTT measures', max_length=15, verbose_name='Was the OGTT repeated?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='repeat_fbg_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first FBG measures', max_length=15, verbose_name='Was the FBG repeated?'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='repeat_ogtt_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='If repeated, must be at least 3 days after the first OGTT measures', max_length=15, verbose_name='Was the OGTT repeated?'),
        ),
    ]



# Generated by Django 3.0.4 on 2020-04-19 20:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0022_auto_20200419_2223"),
    ]

    operations = [
        migrations.AddField(
            model_name="coronakap",
            name="severity_diabetes_hypertension",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                default="true",
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="coronakap",
            name="severity_hiv",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                default="true",
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in people with <u>HIV infection</u>",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="severity_diabetes_hypertension",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                default="true",
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="severity_hiv",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                default="true",
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in people with <u>HIV infection</u>",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="diabetic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="education",
            field=models.CharField(
                choices=[
                    ("primary", "Up to primary"),
                    ("secondary", "Up to high school"),
                    ("tertiary", "University, college"),
                    ("no_education", "No education"),
                ],
                max_length=25,
                verbose_name="What is your highest completed education level?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="employment",
            field=models.CharField(
                choices=[
                    ("professional", "Professional (e.g. office"),
                    ("labourer", "Labourer"),
                    ("housewife_retired", "Housewife, Retired"),
                    ("self_employed", "Small business, self-employed"),
                    ("OTHER", "Other, specify below"),
                ],
                max_length=25,
                verbose_name="What type of employment are you involved in?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="employment_status",
            field=models.CharField(
                choices=[
                    ("working_for_pay", "Working for pay"),
                    ("unemployed", "Unemployed"),
                    (
                        "not_working_for_pay",
                        "Not working for pay (housewife, retired...)",
                    ),
                ],
                max_length=25,
                verbose_name="Are you employed?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="family_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="health_insurance",
            field=models.CharField(
                choices=[
                    ("work_scheme", "Work scheme health insurance"),
                    ("private", "Private health insurance"),
                    ("no_insurance", "No insurance, I pay"),
                    ("OTHER", "Other, please specify below"),
                ],
                max_length=25,
                verbose_name="How are you covered for your health care expenses?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hiv_pos",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>HIV</u> infection?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hot_climate",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus does not survive in the hot climate",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hypertensive",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="know_other_symptoms",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Do you know of any other symptoms of the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="lives_on_materials",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus can live on clothes, plastics, cardboard for a day or more",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="perc_die",
            field=models.IntegerField(
                help_text="On a scale from 0-100",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will die</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="perc_mild_symptom",
            field=models.IntegerField(
                help_text="On a scale from 0-100",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will have only mild symptoms</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="perceived_threat",
            field=models.IntegerField(
                help_text="On a scale from 1-10",
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="On a scale from 1-10, how serious of a public health threat is coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="personal_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>you</u> will get sick from the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="severity_age",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in older people than children",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="shared_housing_two",
            field=models.IntegerField(
                verbose_name="In a typical month, how many different people spend more than one night at your current dwelling?"
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_asymptomatic",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit the coronavirus even when they do not appear to be sick",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_droplets",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_sick",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit the coronavirus when they are sick ",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_touch",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus can spread by people touching each other",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_touch2",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="You can catch the coronavirus if you touch an infected area and then touch your face or eyes",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="symptoms_other",
            field=models.TextField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="Please list any other symptoms of the coronavirus infection that you are aware of",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="wash_hands",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Wash hands with soap and warm water",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="diabetic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>diabetes</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="education",
            field=models.CharField(
                choices=[
                    ("primary", "Up to primary"),
                    ("secondary", "Up to high school"),
                    ("tertiary", "University, college"),
                    ("no_education", "No education"),
                ],
                max_length=25,
                verbose_name="What is your highest completed education level?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="employment",
            field=models.CharField(
                choices=[
                    ("professional", "Professional (e.g. office"),
                    ("labourer", "Labourer"),
                    ("housewife_retired", "Housewife, Retired"),
                    ("self_employed", "Small business, self-employed"),
                    ("OTHER", "Other, specify below"),
                ],
                max_length=25,
                verbose_name="What type of employment are you involved in?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="employment_status",
            field=models.CharField(
                choices=[
                    ("working_for_pay", "Working for pay"),
                    ("unemployed", "Unemployed"),
                    (
                        "not_working_for_pay",
                        "Not working for pay (housewife, retired...)",
                    ),
                ],
                max_length=25,
                verbose_name="Are you employed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="family_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="health_insurance",
            field=models.CharField(
                choices=[
                    ("work_scheme", "Work scheme health insurance"),
                    ("private", "Private health insurance"),
                    ("no_insurance", "No insurance, I pay"),
                    ("OTHER", "Other, please specify below"),
                ],
                max_length=25,
                verbose_name="How are you covered for your health care expenses?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hiv_pos",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>HIV</u> infection?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hot_climate",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus does not survive in the hot climate",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hypertensive",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Does the patient have <u>hypertension</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="know_other_symptoms",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Do you know of any other symptoms of the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="lives_on_materials",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus can live on clothes, plastics, cardboard for a day or more",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="perc_die",
            field=models.IntegerField(
                help_text="On a scale from 0-100",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will die</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="perc_mild_symptom",
            field=models.IntegerField(
                help_text="On a scale from 0-100",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will have only mild symptoms</u>?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="perceived_threat",
            field=models.IntegerField(
                help_text="On a scale from 1-10",
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="On a scale from 1-10, how serious of a public health threat is coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="personal_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>you</u> will get sick from the coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="severity_age",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The disease caused by the coronavirus is more severe in older people than children",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="shared_housing_two",
            field=models.IntegerField(
                verbose_name="In a typical month, how many different people spend more than one night at your current dwelling?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_asymptomatic",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit the coronavirus even when they do not appear to be sick",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_droplets",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_sick",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit the coronavirus when they are sick ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_touch",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="The coronavirus can spread by people touching each other",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_touch2",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="You can catch the coronavirus if you touch an infected area and then touch your face or eyes",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="symptoms_other",
            field=models.TextField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="Please list any other symptoms of the coronavirus infection that you are aware of",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="wash_hands",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Wash hands with soap and warm water",
            ),
        ),
    ]



# Generated by Django 2.2.6 on 2019-11-06 05:28

import uuid

import _socket
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model_fields.fields.other_charfield
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("meta_screening", "0009_auto_20191105_0122"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="consent_ability",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Participant or legal guardian/representative able and willing to give informed consent.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one, or;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="creatinine_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the serum creatinine performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="dia_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in Hg. format DIA, e.g. 80",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(20),
                    django.core.validators.MaxValueValidator(150),
                ],
                verbose_name="Blood pressure: diastolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="hba1c_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the HbA1c performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="height",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="sys_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in mm. format SYS, e.g. 120",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50),
                    django.core.validators.MaxValueValidator(220),
                ],
                verbose_name="Blood pressure: systolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="weight",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="consent_ability",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Participant or legal guardian/representative able and willing to give informed consent.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one, or;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="creatinine_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the serum creatinine performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="dia_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in Hg. format DIA, e.g. 80",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(20),
                    django.core.validators.MaxValueValidator(150),
                ],
                verbose_name="Blood pressure: diastolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="hba1c_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the HbA1c performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="height",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="sys_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in mm. format SYS, e.g. 120",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50),
                    django.core.validators.MaxValueValidator(220),
                ],
                verbose_name="Blood pressure: systolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="weight",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="consent_ability",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Participant or legal guardian/representative able and willing to give informed consent.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one, or;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="creatinine_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the serum creatinine performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="dia_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in Hg. format DIA, e.g. 80",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(20),
                    django.core.validators.MaxValueValidator(150),
                ],
                verbose_name="Blood pressure: diastolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="hba1c_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the HbA1c performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="height",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="sys_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in mm. format SYS, e.g. 120",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50),
                    django.core.validators.MaxValueValidator(220),
                ],
                verbose_name="Blood pressure: systolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="weight",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="consent_ability",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Participant or legal guardian/representative able and willing to give informed consent.",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one, or;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="creatinine_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the serum creatinine performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="dia_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in Hg. format DIA, e.g. 80",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(20),
                    django.core.validators.MaxValueValidator(150),
                ],
                verbose_name="Blood pressure: diastolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="hba1c_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the HbA1c performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="height",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="sys_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in mm. format SYS, e.g. 120",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50),
                    django.core.validators.MaxValueValidator(220),
                ],
                verbose_name="Blood pressure: systolic",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="weight",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="consent_ability",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Participant or legal guardian/representative able and willing to give informed consent.",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one, or;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="creatinine_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the serum creatinine performed?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="dia_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in Hg. format DIA, e.g. 80",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(20),
                    django.core.validators.MaxValueValidator(150),
                ],
                verbose_name="Blood pressure: diastolic",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="hba1c_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Was the HbA1c performed?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="height",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="sys_blood_pressure",
            field=models.IntegerField(
                blank=True,
                help_text="in mm. format SYS, e.g. 120",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50),
                    django.core.validators.MaxValueValidator(220),
                ],
                verbose_name="Blood pressure: systolic",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="weight",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.CreateModel(
            name="SubjectRefusal",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "subject_identifier_as_pk",
                    models.UUIDField(default=uuid.uuid4, editable=False),
                ),
                (
                    "subject_identifier_aka",
                    models.CharField(
                        editable=False,
                        help_text="track a previously allocated identifier.",
                        max_length=50,
                        null=True,
                        verbose_name="Subject Identifier a.k.a",
                    ),
                ),
                ("subject_identifier", models.CharField(editable=False, max_length=50)),
                (
                    "screening_identifier",
                    models.CharField(editable=False, max_length=50),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "reason",
                    models.CharField(
                        choices=[
                            ("dont_have_time", "I don't have time"),
                            ("must_consult_spouse", "I need to consult my spouse"),
                            (
                                "dont_want_blood_drawn",
                                "I don't want to have the blood drawn",
                            ),
                            ("dont_want_to_join", "I don't want to take part"),
                            (
                                "need_to_think_about_it",
                                "I haven't had a chance to think about it",
                            ),
                            ("OTHER", "Other, please specify"),
                        ],
                        max_length=25,
                        verbose_name="Reason for refusal to join",
                    ),
                ),
                (
                    "other_reason",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
                (
                    "subject_screening",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_screening.SubjectScreening",
                    ),
                ),
            ],
            options={
                "verbose_name": "Subject Refusal",
                "verbose_name_plural": "Subject Refusals",
            },
            managers=[("on_site", edc_sites.models.CurrentSiteManager())],
        ),
        migrations.CreateModel(
            name="HistoricalSubjectRefusal",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "subject_identifier_as_pk",
                    models.UUIDField(default=uuid.uuid4, editable=False),
                ),
                (
                    "subject_identifier_aka",
                    models.CharField(
                        editable=False,
                        help_text="track a previously allocated identifier.",
                        max_length=50,
                        null=True,
                        verbose_name="Subject Identifier a.k.a",
                    ),
                ),
                ("subject_identifier", models.CharField(editable=False, max_length=50)),
                (
                    "screening_identifier",
                    models.CharField(editable=False, max_length=50),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "reason",
                    models.CharField(
                        choices=[
                            ("dont_have_time", "I don't have time"),
                            ("must_consult_spouse", "I need to consult my spouse"),
                            (
                                "dont_want_blood_drawn",
                                "I don't want to have the blood drawn",
                            ),
                            ("dont_want_to_join", "I don't want to take part"),
                            (
                                "need_to_think_about_it",
                                "I haven't had a chance to think about it",
                            ),
                            ("OTHER", "Other, please specify"),
                        ],
                        max_length=25,
                        verbose_name="Reason for refusal to join",
                    ),
                ),
                (
                    "other_reason",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
                (
                    "subject_screening",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_screening.SubjectScreening",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Subject Refusal",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



from django import forms
from edc_constants.constants import NO, YES
from edc_form_validators import FormValidator

from ..eligibility import EligibilityPartTwo


class ScreeningPartTwoFormValidator(FormValidator):
    def clean(self):

        self.applicable_if_true(
            self.eligible_part_two, field_applicable="already_fasted"
        )

        self.applicable_if(
            NO, field="already_fasted", field_applicable="advised_to_fast"
        )

        self.required_if_true(self.eligible_part_two, field_required="appt_datetime")

        if self.cleaned_data.get("already_fasted") == NO:
            self.raise_if_not_future_appt_datetime()

        self.required_if(
            YES, field="unsuitable_for_study", field_required="reasons_unsuitable"
        )

    @property
    def eligible_part_two(self) -> bool:
        """Returns False if any of the required fields is YES."""
        eligibility = EligibilityPartTwo(cleaned_data=self.cleaned_data)
        return eligibility.is_eligible

    def raise_if_not_future_appt_datetime(self):
        """Raises if appt_datetime is not future relative to
        part_two_report_datetime.
        """
        appt_datetime = self.cleaned_data.get("appt_datetime")
        report_datetime = self.cleaned_data.get("part_two_report_datetime")
        if appt_datetime and report_datetime:
            tdelta = appt_datetime - report_datetime

            hours = tdelta.seconds / 3600

            if (tdelta.days == 0 and hours < 10) or tdelta.days < 0:
                raise forms.ValidationError(
                    {
                        "appt_datetime": (
                            f"Invalid date. Must be at least 10hrs "
                            f"from report date/time. Got {tdelta.days} "
                            f"days {round(hours,1)} hrs."
                        )
                    }
                )



def get_part_one_fields():
    fields = [
        "report_datetime",
        "screening_consent",
        "meta_phase_two",
        "selection_method",
        "hospital_identifier",
        "initials",
        "gender",
        "age_in_years",
        "ethnicity",
        "hiv_pos",
        "art_six_months",
        "on_rx_stable",
        "vl_undetectable",
        "lives_nearby",
        "staying_nearby_12",
        "pregnant",
        "continue_part_two",
    ]
    return tuple(fields)


def get_part_two_fields():
    fields = [
        "part_two_report_datetime",
        "congestive_heart_failure",
        "liver_disease",
        "alcoholism",
        "acute_metabolic_acidosis",
        "renal_function_condition",
        "tissue_hypoxia_condition",
        "acute_condition",
        "metformin_sensitivity",
        "has_dm",
        "on_dm_medication",
        "already_fasted",
        "advised_to_fast",
        "appt_datetime",
    ]
    return tuple(fields)


def get_part_three_vitals_fields():
    return [
        "height",
        "weight",
        "waist_circumference",
        "sys_blood_pressure_one",
        "dia_blood_pressure_one",
        "sys_blood_pressure_two",
        "dia_blood_pressure_two",
        "severe_htn",
    ]


def get_part_three_fbg_fields():
    return (
        "fasting",
        "fasting_duration_str",
        "fbg_datetime",
        "fbg_value",
        "fbg_units",
    )


part_three_repeat_fbg_fields = (
    "fbg2_datetime",
    "fbg2_value",
    "fbg2_units",
)

part_three_ogtt_fields = (
    "ogtt_base_datetime",
    "ogtt_datetime",
    "ogtt_value",
    "ogtt_units",
)

part_three_repeat_ogtt_fields = (
    "ogtt2_base_datetime",
    "ogtt2_datetime",
    "ogtt2_value",
    "ogtt2_units",
)

part_three_glucose_fields = (
    get_part_three_fbg_fields() + part_three_ogtt_fields + ("repeat_glucose_opinion",)
)

part_three_pregnancy_fields = (
    "urine_bhcg_performed",
    "urine_bhcg_value",
    "urine_bhcg_date",
)

part_three_other_fields = (
    "creatinine_performed",
    "creatinine_value",
    "creatinine_units",
    "hba1c_performed",
    "hba1c_value",
)

part_three_creatinine_fields = (
    "creatinine_performed",
    "creatinine_value",
    "creatinine_units",
)

part_three_hba1c_fields = (
    "hba1c_performed",
    "hba1c_value",
)

part_three_comment_fields = (
    "unsuitable_for_study",
    "reasons_unsuitable",
    "unsuitable_agreed",
)

calculated_fields = (
    "sys_blood_pressure_avg",
    "dia_blood_pressure_avg",
    "calculated_bmi_value",
    "converted_fbg_value",
    "converted_ogtt_value",
    "converted_fbg2_value",
    "converted_ogtt2_value",
    "converted_creatinine_value",
    "calculated_egfr_value",
    "inclusion_a",
    "inclusion_b",
    "inclusion_c",
    "inclusion_d",
)


# META PHASE_THREE ONLY
part_three_labs = (
    "haemoglobin_value",
    "wbc_value",
    "ast_value",
    "alt_value",
    "alp_value",
    "ggt_value",
    "albumin_value",
)


def get_part_three_fields():
    return (
        "part_three_report_datetime",
        *get_part_three_vitals_fields(),
        *part_three_pregnancy_fields,
        *get_part_three_fbg_fields(),
        *part_three_ogtt_fields,
        *part_three_other_fields,
        *part_three_comment_fields,
    )



from edc_protocol_violation.forms import ProtocolDeviationViolationForm as Base

from ..models import ProtocolDeviationViolation


class ProtocolDeviationViolationForm(Base):
    class Meta:
        model = ProtocolDeviationViolation
        fields = "__all__"



from dateutil.relativedelta import relativedelta
from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from django.db.models.signals import post_save, pre_save
from django.dispatch import receiver
from edc_appointment.models import Appointment
from edc_consent.utils import get_consent_model_cls
from edc_pharmacy.utils import create_prescription
from edc_visit_schedule import site_visit_schedules
from edc_visit_schedule.constants import DAY1

from meta_edc.meta_version import get_meta_version
from meta_pharmacy.constants import METFORMIN
from meta_visit_schedule.constants import (
    SCHEDULE_POSTNATAL,
    SCHEDULE_PREGNANCY,
    VISIT_SCHEDULE,
)

from .delivery import Delivery
from .study_medication import StudyMedication
from .subject_visit import SubjectVisit


@receiver(
    pre_save,
    weak=False,
    sender=StudyMedication,
    dispatch_uid="study_medication_on_pre_save",
)
def study_medication_on_pre_save(sender, instance, raw, **kwargs):
    """Create a prescription if one does not exist

    Note: this should not be necessary if consented after meta_consent.signal
          was updated to call `create_prescription`.
    """
    if not raw and instance.subject_visit.visit_code == DAY1:
        subject_consent = get_consent_model_cls().objects.get(
            subject_identifier=instance.subject_visit.subject_identifier,
        )
        create_prescription(
            subject_identifier=subject_consent.subject_identifier,
            report_datetime=subject_consent.consent_datetime,
            randomizer_name=get_meta_version(),
            medication_name=METFORMIN,
        )


@receiver(
    post_save,
    weak=False,
    sender=Delivery,
    dispatch_uid="update_pregnancy_notification_on_delivery_post_save",
)
def update_pregnancy_notification_on_delivery_post_save(
    sender, instance, raw, **kwargs
):
    if not raw:
        model_cls = django_apps.get_model("meta_prn.pregnancynotification")
        model_cls.objects.filter(
            subject_identifier=instance.subject_visit.subject_identifier,
            delivered=False,
            delivery_datetime=None,
        ).update(delivered=True, delivery_datetime=instance.delivery_datetime)


@receiver(
    post_save,
    weak=False,
    sender=Delivery,
    dispatch_uid="update_schedule_on_delivery_post_save",
)
def update_schedule_on_delivery_post_save(sender, instance, raw, **kwargs):
    if not raw:
        offschedule_model_cls = django_apps.get_model("meta_prn.offschedulepregnancy")
        try:
            offschedule_model_cls.objects.get(
                subject_identifier=instance.subject_identifier
            )
        except ObjectDoesNotExist:
            last_subject_visit = (
                SubjectVisit.objects.filter(
                    subject_identifier=instance.subject_identifier,
                    schedule_name=SCHEDULE_PREGNANCY,
                )
                .order_by("report_datetime")
                .last()
            )
            visit_schedule = site_visit_schedules.get_visit_schedule(
                visit_schedule_name=VISIT_SCHEDULE
            )
            schedule = visit_schedule.schedules.get(SCHEDULE_PREGNANCY)
            schedule.take_off_schedule(
                offschedule_datetime=last_subject_visit.report_datetime,
                subject_identifier=instance.subject_identifier,
            )
            schedule = visit_schedule.schedules.get(SCHEDULE_POSTNATAL)

            first_appt_datetime = Appointment.objects.get(
                subject_identifier=instance.subject_identifier,
                visit_code=DAY1,
                visit_code_sequence=0,
                timepoint=0,
            ).appt_datetime + relativedelta(months=36)

            schedule.put_on_schedule(
                onschedule_datetime=last_subject_visit.report_datetime,
                subject_identifier=instance.subject_identifier,
                first_appt_datetime=first_appt_datetime,
            )



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple

from ..admin_site import meta_subject_admin
from ..forms import PregnancyUpdateForm
from ..models import PregnancyUpdate
from .modeladmin import CrfModelAdmin


@admin.register(PregnancyUpdate, site=meta_subject_admin)
class PregnancyUpdateAdmin(CrfModelAdmin):

    form = PregnancyUpdateForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Update",
            {
                "fields": (
                    "contact",
                    "comment",
                )
            },
        ),
        audit_fieldset_tuple,
    )

    radio_fields = {
        "contact": admin.VERTICAL,
    }
